@@ -40,8 +40,8 @@ def wrapMainFunction(dagger_api, func, task_name=None, task_run_id=None):
         task = None
         try:
             task_input = dict(
-                args=*args,
-                kwargs=**kwargs
+                args=args,
+                kwargs=kwargs
             )
 
             task_metadata = dict(
